Path class

Constructors

Path(String pattern, PathWidgetBuilder builder, {bool openInSecondScreen = false})
const

Properties

builder → PathWidgetBuilder
The builder for the associated pattern route. The first argument is the BuildContext and the second argument a RegEx match if that is included in the pattern.
final
hashCode → int
The hash code for this object.
no setterinherited
openInSecondScreen → bool
If the route should open on the second screen on foldables.
final
pattern → String
A RegEx string for route matching.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited